@@ -123,7 +123,12 @@ class PluginManifest(ImportExportModel):
         "For normal (non-dynamic) plugins, this data will come from the package's "
         "setup.cfg",
         hide_docs=True,
-        exclude=True,
+    )
+
+    npe1_shim: bool = Field(
+        False,
+        description="Whether this manifest was created as a shim for an npe1 plugin.",
+        hide_docs=True,
     )
 
     def __init__(self, **data):
